@@ -1,6 +1,6 @@
 package Hubot::Scripts::tell;
 {
-  $Hubot::Scripts::tell::VERSION = '0.0.7';
+  $Hubot::Scripts::tell::VERSION = '0.0.8';
 }
 use strict;
 use warnings;
@@ -11,29 +11,37 @@ sub load {
     $robot->respond(
         qr/(tell (\w+) (?:.+))$/i,
         sub {
-            my $msg = shift;
+            my $msg    = shift;
             my $sender = $msg->message->user->{name};
             my ( $post, $recipient ) = ( $msg->match->[0], $msg->match->[1] );
+
             # XXX: hey, There should be generalized nick matchers, supplied from each adapters.
-            if (my ($user) = grep /^$recipient$/i, keys %{$robot->brain->{data}{users}}) {
+            if ( my ($user) = grep /^$recipient$/i,
+                keys %{ $robot->brain->{data}{users} } )
+            {
                 # XXX: hey, I can't detect if a user is awake or idle.
-                $msg->reply( "<$recipient> $msg" );
-            } else {
+                $msg->reply("<$recipient> $msg");
+            }
+            else {
                 # XXX: hey, There is no time provided from adapters for messages.
-                my $dt = DateTime->now(time_zone => 'Asia/Seoul');
-                $robot->brain->{data}{tell}{$recipient}{+time} = [ $sender, $recipient, $post, $dt->ymd." ".$dt->hms ];
-                $msg->reply( "OK, I'll pass that on when $recipient is around." );
+                my $dt = DateTime->now( time_zone => 'Asia/Seoul' );
+                $robot->brain->{data}{tell}{$recipient}{ +time } =
+                  [ $sender, $recipient, $post, $dt->ymd . " " . $dt->hms ];
+                $msg->reply("OK, I'll pass that on when $recipient is around.");
             }
         }
     );
     $robot->enter(
         sub {
-            my $msg = shift;
+            my $msg  = shift;
             my $user = $msg->message->user->{name};
-            for my $recipient (keys %{$robot->brain->{data}{tell}}) {
-                if ($user =~ /^$recipient$/i) {
-                    for my $post (values %{$robot->brain->{data}{tell}{$recipient}}) {
-                        $msg->send( "$user: $post->[3]: <$post->[0]> $post->[2]" );
+            for my $recipient ( keys %{ $robot->brain->{data}{tell} } ) {
+                if ( $user =~ /^$recipient$/i ) {
+                    for my $post (
+                        values %{ $robot->brain->{data}{tell}{$recipient} } )
+                    {
+                        $msg->send(
+                            "$user: $post->[3]: <$post->[0]> $post->[2]");
                     }
                     delete $robot->brain->{data}{tell}{$recipient};
                 }
